<img src="./developer/agpl-license-web-badge-version-2-256x48.png"/> 

[![Build Status](https://app.travis-ci.com/hasii2011/ogl.svg?branch=master)](https://app.travis-ci.com/hasii2011/ogl)
[![Maintenance](https://img.shields.io/badge/Maintained%3F-yes-green.svg)](https://GitHub.com/Naereen/StrapDown.js/graphs/commit-activity)
[![CircleCI](https://dl.circleci.com/status-badge/img/gh/hasii2011/ogl/tree/master.svg?style=shield)](https://dl.circleci.com/status-badge/redirect/gh/hasii2011/ogl/tree/master)
[![macOS](https://svgshare.com/i/ZjP.svg)](https://svgshare.com/i/ZjP.svg)

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)

𝓟 𝓨 𝓤 𝓣 stands for Python UML Tool. This is the external graphical shapes module for Pyut
that allows for external plugin development;

This project depends on pyutmodel and wxPython


------


![Humberto's Modified Logo](https://raw.githubusercontent.com/wiki/hasii2011/gittodoistclone/images/SillyGitHub.png)

I am concerned about GitHub's Copilot project



I urge you to read about the
[Give up GitHub](https://GiveUpGitHub.org) campaign from
[the Software Freedom Conservancy](https://sfconservancy.org).

While I do not advocate for all the issues listed there I do not like that
a company like Microsoft may profit from open source projects.

I continue to use GitHub because it offers the services I need for free.  But, I continue
to monitor their terms of service.

Any use of this project's code by GitHub Copilot, past or present, is done
without my permission.  I do not consent to GitHub's use of this project's
code in Copilot.

A repository owner may opt out of Copilot by changing Settings --> GitHub Copilot.

I have done so.
